.. architecture-ref

|Enaml| Architecture Reference
===============================================================================

.. warning:: This documentation is not current and does not reflect the way
    Enaml currently works.

.. toctree::
   :maxdepth: 2

   architecture
